@@ -76,6 +76,7 @@
 //! - `smol_str`: Integrate with the [`smol_str` crate](https://crates.io/crates/smol_str).
 //! - `hashbrown`: Integrate with the [`hashbrown` crate](https://github.com/rust-lang/hashbrown).
 //! - `time`: Integrate with the [`time` crate](https://github.com/time-rs/time).
+//! - `unstable_oneof`: Enable the `OneofObject` macro to define the oneof input object.
 //!
 //! ## Integrations
 //!
@@ -266,6 +267,10 @@ pub use async_graphql_derive::MergedSubscription;
 pub use async_graphql_derive::NewType;
 #[doc = include_str!("docs/object.md")]
 pub use async_graphql_derive::Object;
+#[cfg(feature = "unstable_oneof")]
+#[cfg_attr(docsrs, doc(cfg(feature = "unstable_oneof")))]
+#[doc = include_str!("docs/oneof_object.md")]
+pub use async_graphql_derive::OneofObject;
 #[doc = include_str!("docs/scalar.md")]
 pub use async_graphql_derive::Scalar;
 #[doc = include_str!("docs/simple_object.md")]
